@@ -1,11 +1,8 @@
-from __future__ import unicode_literals
-
 import json
 import logging
+import urllib.parse
 
 import requests
-import six
-from six.moves.urllib.parse import quote
 
 from globus_sdk import config, exc
 from globus_sdk.response import GlobusHTTPResponse
@@ -35,7 +32,7 @@ class ClientLogAdapter(logging.LoggerAdapter):
         return self.warning(*args, **kwargs)
 
 
-class BaseClient(object):
+class BaseClient:
     r"""
     Simple client with error handling for Globus REST APIs. Implemented
     as a wrapper around a ``requests.Session`` object, with a simplified
@@ -64,7 +61,7 @@ class BaseClient(object):
     # a collection of authorizer types, or None to indicate "any"
     allowed_authorizer_types = None
 
-    BASE_USER_AGENT = "globus-sdk-py-{0}".format(__version__)
+    BASE_USER_AGENT = f"globus-sdk-py-{__version__}"
 
     def __init__(
         self,
@@ -76,7 +73,7 @@ class BaseClient(object):
         app_name=None,
         http_timeout=None,
         *args,
-        **kwargs
+        **kwargs,
     ):
         self._init_logger_adapter()
         self.logger.info(
@@ -94,8 +91,7 @@ class BaseClient(object):
             )
             raise exc.GlobusSDKUsageError(
                 (
-                    "{0} can only take authorizers from {1}, "
-                    "but you have provided {2}"
+                    "{} can only take authorizers from {}, but you have provided {}"
                 ).format(type(self), self.allowed_authorizer_types, type(authorizer))
             )
 
@@ -186,10 +182,10 @@ class BaseClient(object):
         interacting with Globus Support.
         """
         self.app_name = app_name
-        self._headers["User-Agent"] = "{0}/{1}".format(self.BASE_USER_AGENT, app_name)
+        self._headers["User-Agent"] = f"{self.BASE_USER_AGENT}/{app_name}"
 
     def qjoin_path(self, *parts):
-        return "/" + "/".join(quote(part) for part in parts)
+        return "/" + "/".join(urllib.parse.quote(part) for part in parts)
 
     def get(self, path, params=None, headers=None, response_class=None, retry_401=True):
         """
@@ -211,7 +207,7 @@ class BaseClient(object):
         :return: :class:`GlobusHTTPResponse \
         <globus_sdk.response.GlobusHTTPResponse>` object
         """
-        self.logger.debug("GET to {} with params {}".format(path, params))
+        self.logger.debug(f"GET to {path} with params {params}")
         return self._request(
             "GET",
             path,
@@ -255,7 +251,7 @@ class BaseClient(object):
         :return: :class:`GlobusHTTPResponse \
         <globus_sdk.response.GlobusHTTPResponse>` object
         """
-        self.logger.debug("POST to {} with params {}".format(path, params))
+        self.logger.debug(f"POST to {path} with params {params}")
         return self._request(
             "POST",
             path,
@@ -289,7 +285,7 @@ class BaseClient(object):
         :return: :class:`GlobusHTTPResponse \
         <globus_sdk.response.GlobusHTTPResponse>` object
         """
-        self.logger.debug("DELETE to {} with params {}".format(path, params))
+        self.logger.debug(f"DELETE to {path} with params {params}")
         return self._request(
             "DELETE",
             path,
@@ -333,7 +329,7 @@ class BaseClient(object):
         :return: :class:`GlobusHTTPResponse \
         <globus_sdk.response.GlobusHTTPResponse>` object
         """
-        self.logger.debug("PUT to {} with params {}".format(path, params))
+        self.logger.debug(f"PUT to {path} with params {params}")
         return self._request(
             "PUT",
             path,
@@ -379,7 +375,7 @@ class BaseClient(object):
         :return: :class:`GlobusHTTPResponse \
         <globus_sdk.response.GlobusHTTPResponse>` object
         """
-        self.logger.debug("PATCH to {} with params {}".format(path, params))
+        self.logger.debug(f"PATCH to {path} with params {params}")
         return self._request(
             "PATCH",
             path,
@@ -451,7 +447,7 @@ class BaseClient(object):
             self.authorizer.set_authorization_header(rheaders)
 
         url = slash_join(self.base_url, path)
-        self.logger.debug("request will hit URL:{}".format(url))
+        self.logger.debug(f"request will hit URL:{url}")
 
         # because a 401 can trigger retry, we need to wrap the retry-able thing
         # in a method
@@ -473,7 +469,7 @@ class BaseClient(object):
         # initial request
         r = send_request()
 
-        self.logger.debug("Request made to URL: {}".format(r.url))
+        self.logger.debug(f"Request made to URL: {r.url}")
 
         # potential 401 retry handling
         if r.status_code == 401 and retry_401 and self.authorizer is not None:
@@ -488,16 +484,14 @@ class BaseClient(object):
                 r = send_request()
 
         if 200 <= r.status_code < 400:
-            self.logger.debug(
-                "request completed with response code: {}".format(r.status_code)
-            )
+            self.logger.debug(f"request completed with response code: {r.status_code}")
             if response_class is None:
                 return self.default_response_class(r, client=self)
             else:
                 return response_class(r, client=self)
 
         self.logger.debug(
-            "request completed with (error) response code: {}".format(r.status_code)
+            f"request completed with (error) response code: {r.status_code}"
         )
         raise self.error_class(r)
 
@@ -564,12 +558,11 @@ def merge_params(base_params, **more_params):
 def safe_stringify(value):
     """
     Converts incoming value to a unicode string. Convert bytes by decoding,
-    anything else has __str__ called, then is converted to bytes and then to
-    unicode to deal with python 2 and 3 differing in definitions of string
+    anything else has __str__ called.
+    Strings are checked to avoid duplications
     """
-    if isinstance(value, six.text_type):
+    if isinstance(value, str):
         return value
     if isinstance(value, bytes):
         return value.decode("utf-8")
-    else:
-        return six.b(str(value)).decode("utf-8")
+    return str(value)
